'use strict';

exports.__esModule = true;

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _d3 = require('d3');

var d3 = _interopRequireWildcard(_d3);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var margin = {
  top: 20,
  right: 20,
  bottom: 30,
  left: 40
};

var MultiLineChart = (function (_React$PureComponent) {
  _inherits(MultiLineChart, _React$PureComponent);

  function MultiLineChart() {
    var _this = this;

    _classCallCheck(this, MultiLineChart);

    _React$PureComponent.apply(this, arguments);

    this.setSvg = function (svg) {
      if (svg) {
        d3.select(svg).selectAll('g').remove();
        _this.draw(d3.select(svg));
      }
    };

    this.draw = function (svg) {
      var _props = _this.props;
      var data = _props.data;
      var width = _props.width;
      var height = _props.height;

      var x = d3.scaleTime().domain(d3.extent(data.dates)).range([margin.left, width - margin.right]);

      var y = d3.scaleLinear().domain([0, d3.max(data.series, function (d) {
        return d3.max(d.values);
      })]).nice().range([height - margin.bottom, margin.top]);

      var xAxis = function xAxis(g) {
        return g.attr('transform', 'translate(0,' + (height - margin.bottom) + ')').call(d3.axisBottom(x).ticks(width / 80).tickSizeOuter(0));
      };

      var yAxis = function yAxis(g) {
        return g.attr('transform', 'translate(' + margin.left + ',0)').call(d3.axisLeft(y)).call(function (g) {
          return g.select('.domain').remove();
        }).call(function (g) {
          return g.select('.tick:last-of-type text').clone().attr('x', 3).attr('text-anchor', 'start').attr('font-weight', 'bold').text(data.y);
        });
      };

      var line = d3.line().defined(function (d) {
        return !isNaN(d);
      }).x(function (d, i) {
        return x(data.dates[i]);
      }).y(function (d) {
        return y(d);
      });

      svg.append('g').call(xAxis);

      svg.append('g').call(yAxis);

      var path = svg.append('g').attr('fill', 'none').attr('stroke', 'steelblue').attr('stroke-width', 1.5).attr('stroke-linejoin', 'round').attr('stroke-linecap', 'round').selectAll('path').data(data.series).enter().append('path').style('mix-blend-mode', 'multiply').attr('d', function (d) {
        return line(d.values);
      });

      svg.call(_this.hover(x, y, data), path);

      return svg.node();
    };

    this.hover = function (x, y, data) {
      return function (svg, path) {
        svg.style('position', 'relative');

        if ('ontouchstart' in document) svg.style('-webkit-tap-highlight-color', 'transparent').on('touchmove', moved).on('touchstart', entered).on('touchend', left);else svg.on('mousemove', moved).on('mouseenter', entered).on('mouseleave', left);

        var dot = svg.append('g').attr('display', 'none');

        dot.append('circle').attr('r', 2.5);

        dot.append('text').style('font', '10px sans-serif').attr('text-anchor', 'middle').attr('y', -8);

        function moved() {
          d3.event.preventDefault();
          var ym = y.invert(d3.event.layerY);
          var xm = x.invert(d3.event.layerX);
          var i1 = d3.bisectLeft(data.dates, xm, 1);
          var i0 = i1 - 1;
          var i = xm - data.dates[i0] > data.dates[i1] - xm ? i1 : i0;
          var s = data.series.reduce(function (a, b) {
            return Math.abs(a.values[i] - ym) < Math.abs(b.values[i] - ym) ? a : b;
          });
          path.attr('stroke', function (d) {
            return d === s ? null : '#ddd';
          }).filter(function (d) {
            return d === s;
          }).raise();
          dot.attr('transform', 'translate(' + x(data.dates[i]) + ',' + y(s.values[i]) + ')');
          dot.select('text').text(s.name);
        }

        function entered() {
          path.style('mix-blend-mode', null).attr('stroke', '#ddd');
          dot.attr('display', null);
        }

        function left() {
          path.style('mix-blend-mode', 'multiply').attr('stroke', null);
          dot.attr('display', 'none');
        }
      };
    };
  }

  MultiLineChart.prototype.render = function render() {
    var _props2 = this.props;
    var width = _props2.width;
    var height = _props2.height;

    return _react2['default'].createElement('svg', { ref: this.setSvg, width: width, height: height });
  };

  _createClass(MultiLineChart, null, [{
    key: 'propTypes',
    value: {
      data: _propTypes2['default'].object.isRequired,
      width: _propTypes2['default'].number.isRequired,
      height: _propTypes2['default'].number.isRequired
    },
    enumerable: true
  }]);

  return MultiLineChart;
})(_react2['default'].PureComponent);

exports['default'] = MultiLineChart;
module.exports = exports['default'];