import React from 'react'
import * as d3 from 'd3'
import PropTypes from 'prop-types'

const margin = {
  top: 20,
  right: 30,
  bottom: 30,
  left: 40
}

class LineChart extends React.PureComponent {
  static propTypes = {
    data: PropTypes.array.isRequired,
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired
  }

  setSvg = svg => {
    if (svg) {
      d3.select(svg)
        .selectAll('g')
        .remove()
      this.draw(d3.select(svg))
    }
  }

  draw = svg => {
    const { data, width, height } = this.props

    const x = d3
      .scaleTime()
      .domain(d3.extent(data, d => d.date))
      .range([margin.left, width - margin.right])

    const y = d3
      .scaleLinear()
      .domain([0, d3.max(data, d => d.value)])
      .nice()
      .range([height - margin.bottom, margin.top])

    const xAxis = g =>
      g.attr('transform', `translate(0,${height - margin.bottom})`).call(
        d3
          .axisBottom(x)
          .ticks(width / 80)
          .tickSizeOuter(0)
      )

    const yAxis = g =>
      g
        .attr('transform', `translate(${margin.left},0)`)
        .call(d3.axisLeft(y))
        .call(g => g.select('.domain').remove())
        .call(g =>
          g
            .select('.tick:last-of-type text')
            .clone()
            .attr('x', 3)
            .attr('text-anchor', 'start')
            .attr('font-weight', 'bold')
            .text(data.y)
        )

    const line = d3
      .line()
      .defined(d => !isNaN(d.value))
      .x(d => x(d.date))
      .y(d => y(d.value))

    svg.append('g').call(xAxis)

    svg.append('g').call(yAxis)

    svg
      .append('path')
      .datum(data)
      .attr('fill', 'none')
      .attr('stroke', 'steelblue')
      .attr('stroke-width', 1.5)
      .attr('stroke-linejoin', 'round')
      .attr('stroke-linecap', 'round')
      .attr('d', line)
  }

  render() {
    const { width, height } = this.props

    return <svg ref={this.setSvg} width={width} height={height} />
  }
}

export default LineChart
