import * as d3 from 'd3'

export const format = d3.format(',d')

export const getTitle = d => d.data.id + '\n' + format(d.value)

export const getRate = d => {
  if (!d.children) {
    return `</br>${format(d.data.rate)}%`
  } else {
    return ''
  }
}

export const sumBySize = d => d.size

export const eachBefore = d => {
  d.data.id = (d.parent ? d.parent.data.id + '.' : '') + d.data.name
}

export const sort = (a, b) => b.height - a.height || b.value - a.value

export const getName = d => d.data.name

export const getUrlId = d => `url(#clip-${d.data.id})`

export const getHrefId = d => `#${d.data.id}`

export const getClipId = d => `clip-${d.data.id}`

export const getId = d => d.data.id

export const getTransform = d => `translate(${d.x0},${d.y0})`

export const getHeight = d => d.y1 - d.y0

export const getWidth = d => d.x1 - d.x0

export const getBlockStyle = d => {
  if (!d.children) {
    return `width:${getWidth(d)}px;height:${getHeight(d)}px;
    display:flex;justify-content:center;align-items:center;font-family:sans-serif;`
  }
  return `width:${getWidth(d)}px;height:30px;
  display:flex;justify-content:center;align-items:center;font-family:sans-serif;background:rgba(0,0,0,0.3);`
}

export const getParagraphStyle = d => {
  if (!d.children) {
    return `text-align:center;word-wrap:break-word;max-width:${getWidth(d)}px;`
  }
  return `text-align:center;word-wrap:break-word;max-width:${getWidth(
    d
  )}px;color:black;`
}

export const setColor = d => {
  if (d.children) {
    return 'rgba(0,0,0,0.1)'
  }

  return `rgb(${100 + Math.floor(-+d.data.rate * 30)}, ${100 +
    Math.floor(+d.data.rate * 30)},
    ${Math.floor(-+d.data.rate * 30)})`
}
