import React from 'react'
import ReactDOM from 'react-dom'

import { TreeMap, LineChart, MultiLineChart } from '.'
import { testData } from './data'

const options = ['TreeMap', 'LineChart', 'MultiLineChart']

class RootComponent extends React.PureComponent {
  state = {
    currentOption: 0
  }

  changeOption = () => {
    const { currentOption } = this.state

    this.setState({
      currentOption: currentOption < options.length - 1 ? currentOption + 1 : 0
    })
  }

  render() {
    const { currentOption } = this.state

    return (
      <div>
        <button onClick={this.changeOption}> Change layout </button>
        <h2>{options[currentOption]}</h2>
        {
          [
            <TreeMap
              key={currentOption}
              data={testData[currentOption]}
              width={window.innerWidth}
              height={window.innerHeight}
            />,
            <LineChart
              key={currentOption}
              data={testData[currentOption]}
              width={window.innerWidth}
              height={window.innerHeight}
            />,
            <MultiLineChart
              key={currentOption}
              data={testData[currentOption]}
              width={window.innerWidth}
              height={window.innerHeight}
            />
          ][currentOption]
        }
        <h4>Data: </h4>
        <div>
          <pre>{JSON.stringify(testData[currentOption], undefined, 2)}</pre>
        </div>
      </div>
    )
  }
}

const rootElement = document.getElementById('root')

ReactDOM.render(<RootComponent />, rootElement)
